@@ -1,14 +1,15 @@
 package NewRelic::Agent;
 use strict;
 use warnings;
-use Method::Signatures;
 
-our $VERSION = '0.0510';
+our $VERSION = '0.0532';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
-method new(%args) {
+sub new {
+    my ($self, %args) = @_;
+
     my $license_key          = delete $args{license_key}
                             || $ENV{NEWRELIC_LICENSE_KEY}
                             || '';
@@ -22,7 +23,12 @@ method new(%args) {
                             || $ENV{NEWRELIC_APP_LANGUAGE_VERSION}
                             || $];
 
-    $self->_new($license_key, $app_name, $app_language, $app_language_version);
+    if (%args) {
+        require Carp;
+        Carp::croak("Invalid arguments: @{[ keys %args ]}");
+    }
+
+    return $self->_new($license_key, $app_name, $app_language, $app_language_version);
 }
 
 1;
@@ -41,7 +47,7 @@ NewRelic::Agent - Perl Agent for NewRelic APM
 
 =head1 VERSION
 
-version 0.0510
+version 0.0532
 
 =head1 SYNOPSIS
 
@@ -356,6 +362,30 @@ feature.
 
 Ali Anari <ali@anari.me>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Slobodan Mišković Tatsuhiko Miyagawa Tim Bunce
+
+=over 4
+
+=item *
+
+Slobodan Mišković <slobodan@miskovic.ca>
+
+=item *
+
+Tatsuhiko Miyagawa <miyagawa@bulknews.net>
+
+=item *
+
+Tim Bunce <tim.bunce@pobox.com>
+
+=item *
+
+Tim Bunce <tim@tigerlms.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Ali Anari.
